summaryrefslogtreecommitdiffstats
path: root/media/base/pipeline.h
diff options
context:
space:
mode:
authormiu@chromium.org <miu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-06-13 23:20:45 +0000
committermiu@chromium.org <miu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-06-13 23:20:45 +0000
commit1bd38bd28cbb8daa623541dcdeee55ad33e4bd15 (patch)
tree932b934243d5d9707c9bc4d5c6b87c30ba7beeee /media/base/pipeline.h
parentf805162421d58615a6b6e9b2ebe4872bc208bc38 (diff)
downloadchromium_src-1bd38bd28cbb8daa623541dcdeee55ad33e4bd15.zip
chromium_src-1bd38bd28cbb8daa623541dcdeee55ad33e4bd15.tar.gz
chromium_src-1bd38bd28cbb8daa623541dcdeee55ad33e4bd15.tar.bz2
Replace erroneous use of base::Time with base::TimeTicks throughout media code.
This change corrects all the "low-hanging fruit," leaving the VideoCaptureDevice interface and MediaLog (?) as separate changes; as they are referenced throughout other components. Added a PRESUBMIT.py script for media/ code that will scan future code changes for use of base::Time (or base::Clock/DefaultClock) and prompt the developer with a warning explaining that clock skew is a serious and subtle source of bugs. Testing: Ran all media_unittests and content_unittests. Manually ran through demo sites that utilize all of the following (on all of Win/Mac/Linux): 1. HTML5 audio and video; 2. PPAPI Flash video; 3. WebAudio API; 4. WebRTC; 5. Tab Capture API. BUG=247881 TEST=media_unittests, content_unittests, manual confirmation of major media use cases Review URL: https://chromiumcodereview.appspot.com/16823003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@206206 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'media/base/pipeline.h')
-rw-r--r--media/base/pipeline.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/media/base/pipeline.h b/media/base/pipeline.h
index 0ca7d62..09ff904 100644
--- a/media/base/pipeline.h
+++ b/media/base/pipeline.h
@@ -11,7 +11,7 @@
#include "base/synchronization/condition_variable.h"
#include "base/synchronization/lock.h"
#include "base/threading/thread_checker.h"
-#include "base/time/default_clock.h"
+#include "base/time/default_tick_clock.h"
#include "media/base/audio_renderer.h"
#include "media/base/demuxer.h"
#include "media/base/media_export.h"
@@ -373,8 +373,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
// the filters.
float playback_rate_;
- // base::Clock used by |clock_|.
- base::DefaultClock default_clock_;
+ // base::TickClock used by |clock_|.
+ base::DefaultTickClock default_tick_clock_;
// Reference clock. Keeps track of current playback time. Uses system
// clock and linear interpolation, but can have its time manually set
@@ -439,7 +439,7 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
// Time of pipeline creation; is non-zero only until the pipeline first
// reaches "kStarted", at which point it is used & zeroed out.
- base::Time creation_time_;
+ base::TimeTicks creation_time_;
scoped_ptr<SerialRunner> pending_callbacks_;